pub struct CallFunctionTaskDefinitionBuilder { /* private fields */ }Expand description
Builder for constructing a call task that invokes a function.
Implementations
Sourceimpl CallFunctionTaskDefinitionBuilder
impl CallFunctionTaskDefinitionBuilder
pub fn new(function: &str) -> Self
Sourcepub fn with(&mut self, name: &str, value: Value) -> &mut Self
pub fn with(&mut self, name: &str, value: Value) -> &mut Self
Adds a single named argument to the function call.
Sourcepub fn with_arguments(&mut self, arguments: HashMap<String, Value>) -> &mut Self
pub fn with_arguments(&mut self, arguments: HashMap<String, Value>) -> &mut Self
Replaces all function call arguments with the provided map.