TaskDefinitionBuilder

Struct TaskDefinitionBuilder 

pub struct TaskDefinitionBuilder { /* private fields */ }
Primary entry point for building workflow task definitions.

Supports all task types: call, do, emit, for, fork, listen, raise, run, set, switch, try, and wait.

Implementations

Source

impl TaskDefinitionBuilder

pub fn new() -> Self

pub fn call(&mut self, function: &str) -> &mut CallFunctionTaskDefinitionBuilder

pub fn do_(&mut self) -> &mut DoTaskDefinitionBuilder

pub fn for_(&mut self) -> &mut ForTaskDefinitionBuilder

pub fn fork(&mut self) -> &mut ForkTaskDefinitionBuilder

pub fn listen(&mut self) -> &mut ListenTaskDefinitionBuilder

pub fn raise(&mut self) -> &mut RaiseTaskDefinitionBuilder

pub fn run(&mut self) -> &mut RunTaskDefinitionBuilder

pub fn set(&mut self) -> &mut SetTaskDefinitionBuilder

pub fn switch(&mut self) -> &mut SwitchTaskDefinitionBuilder

pub fn try_(&mut self) -> &mut TryTaskDefinitionBuilder

pub fn wait( &mut self, duration: OneOfDurationOrIso8601Expression, ) -> &mut WaitTaskDefinitionBuilder

pub fn emit<F>(&mut self, setup: F) -> &mut EmitTaskDefinitionBuilder

Creates an emit task that produces a workflow event.

pub fn build(self) -> TaskDefinition

Builds the final TaskDefinition, panicking if no task type was configured.